##
##  libzdb.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         libzdb
Summary:      Zild Database Library
URL:          http://www.tildeslash.com/libzdb/
Vendor:       Tildeslash Ltd.
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Database
License:      GPL (with exceptions)
Version:      3.4.0
Release:      20240801

#   package options
%option       with_sqlite         yes
%option       with_mysql          no
%option       with_pgsql          no

#   list of sources
Source0:      http://www.tildeslash.com/libzdb/dist/libzdb-%{version}.tar.gz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101
PreReq:       OpenPKG, openpkg >= 20160101
%if "%{with_sqlite}" == "yes"
BuildPreReq:  sqlite
PreReq:       sqlite
%endif
%if "%{with_mysql}" == "yes"
BuildPreReq:  mysql, zlib
PreReq:       mysql, zlib
%endif
%if "%{with_pgsql}" == "yes"
BuildPreReq:  openssl, postgresql
PreReq:       openssl, postgresql
%endif

%description
    The Zild C Database Library implements a small, fast, and easy to
    use database API with thread-safe connection pooling. The library
    can connect transparently to multiple database systems, has zero
    configuration and connections are specified via a standard URL
    scheme.

%track
    prog libzdb = {
        version   = %{version}
        url       = http://www.tildeslash.com/libzdb/dist/
        regex     = libzdb-(__VER__)\.tar\.gz
    }

%prep
    %setup -q

%build
    libs=""
%if "%{with_sqlite}" == "yes"
    libs="$libs -lsqlite3"
%endif
%if "%{with_pgsql}" == "yes"
    libs="$libs -lssl -lcrypto -lcrypt"
%endif
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags}" \
    LIBS="$libs" \
    ./configure \
        --prefix=%{l_prefix} \
%if "%{with_sqlite}" == "yes"
        --with-sqlite=%{l_prefix} \
%else
        --without-sqlite \
%endif
%if "%{with_mysql}" == "yes"
        --with-mysql=%{l_prefix} \
%else
        --without-mysql \
%endif
%if "%{with_pgsql}" == "yes"
        --with-postgresql=%{l_prefix}/bin \
%else
        --without-postgresql \
%endif
        --disable-shared
    %{l_make} %{l_mflags} clean || true
    %{l_make} %{l_mflags -O}

%install
    %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

